@@ -2,7 +2,7 @@
 -- pgsql.sql
 -- DB definition for IDO Postgresql
 --
--- Copyright (c) 2009-2016 Icinga Development Team (https://www.icinga.org/)
+-- Copyright (c) 2009-2018 Icinga Development Team (https://www.icinga.com/)
 --
 -- --------------------------------------------------------
 
@@ -10,12 +10,14 @@
 -- Functions
 --
 
-CREATE OR REPLACE FUNCTION from_unixtime(bigint) RETURNS timestamp with time zone AS '
-         SELECT to_timestamp($1) AS result
-' LANGUAGE sql;
+DROP FUNCTION IF EXISTS from_unixtime(bigint);
+CREATE FUNCTION from_unixtime(bigint) RETURNS timestamp AS $$
+  SELECT to_timestamp($1) AT TIME ZONE 'UTC' AS result
+$$ LANGUAGE sql;
 
-CREATE OR REPLACE FUNCTION unix_timestamp(timestamp with time zone) RETURNS bigint AS '
-        SELECT EXTRACT(EPOCH FROM $1)::bigint AS result;
+DROP FUNCTION IF EXISTS unix_timestamp(timestamp WITH TIME ZONE);
+CREATE OR REPLACE FUNCTION unix_timestamp(timestamp) RETURNS bigint AS '
+  SELECT CAST(EXTRACT(EPOCH FROM $1) AS bigint) AS result;
 ' LANGUAGE sql;
 
 
@@ -54,7 +56,7 @@ $$ LANGUAGE plpgsql;
 CREATE TABLE  icinga_acknowledgements (
   acknowledgement_id bigserial,
   instance_id bigint default 0,
-  entry_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  entry_time timestamp,
   entry_time_usec INTEGER  default 0,
   acknowledgement_type INTEGER  default 0,
   object_id bigint default 0,
@@ -64,7 +66,7 @@ CREATE TABLE  icinga_acknowledgements (
   is_sticky INTEGER  default 0,
   persistent_comment INTEGER  default 0,
   notify_contacts INTEGER  default 0,
-  end_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  end_time timestamp,
   CONSTRAINT PK_acknowledgement_id PRIMARY KEY (acknowledgement_id)
 ) ;
 
@@ -80,6 +82,7 @@ CREATE TABLE  icinga_commands (
   config_type INTEGER  default 0,
   object_id bigint default 0,
   command_line TEXT  default '',
+  config_hash varchar(64) DEFAULT NULL,
   CONSTRAINT PK_command_id PRIMARY KEY (command_id) ,
   CONSTRAINT UQ_commands UNIQUE (instance_id,object_id,config_type)
 ) ;
@@ -93,24 +96,23 @@ CREATE TABLE  icinga_commands (
 CREATE TABLE  icinga_commenthistory (
   commenthistory_id bigserial,
   instance_id bigint default 0,
-  entry_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  entry_time timestamp,
   entry_time_usec INTEGER  default 0,
   comment_type INTEGER  default 0,
   entry_type INTEGER  default 0,
   object_id bigint default 0,
-  comment_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  comment_time timestamp,
   internal_comment_id bigint default 0,
   author_name TEXT  default '',
   comment_data TEXT  default '',
   is_persistent INTEGER  default 0,
   comment_source INTEGER  default 0,
   expires INTEGER  default 0,
-  expiration_time timestamp with time zone default '1970-01-01 00:00:00+00',
-  deletion_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  expiration_time timestamp,
+  deletion_time timestamp,
   deletion_time_usec INTEGER  default 0,
   name TEXT default NULL,
-  CONSTRAINT PK_commenthistory_id PRIMARY KEY (commenthistory_id) ,
-  CONSTRAINT UQ_commenthistory UNIQUE (instance_id,object_id,comment_time,internal_comment_id)
+  CONSTRAINT PK_commenthistory_id PRIMARY KEY (commenthistory_id)
 );
 
 -- --------------------------------------------------------
@@ -122,22 +124,22 @@ CREATE TABLE  icinga_commenthistory (
 CREATE TABLE  icinga_comments (
   comment_id bigserial,
   instance_id bigint default 0,
-  entry_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  entry_time timestamp,
   entry_time_usec INTEGER  default 0,
   comment_type INTEGER  default 0,
   entry_type INTEGER  default 0,
   object_id bigint default 0,
-  comment_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  comment_time timestamp,
   internal_comment_id bigint default 0,
   author_name TEXT  default '',
   comment_data TEXT  default '',
   is_persistent INTEGER  default 0,
   comment_source INTEGER  default 0,
   expires INTEGER  default 0,
-  expiration_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  expiration_time timestamp,
   name TEXT default NULL,
-  CONSTRAINT PK_comment_id PRIMARY KEY (comment_id) ,
-  CONSTRAINT UQ_comments UNIQUE (instance_id,object_id,comment_time,internal_comment_id)
+  session_token INTEGER default NULL,
+  CONSTRAINT PK_comment_id PRIMARY KEY (comment_id)
 )  ;
 
 -- --------------------------------------------------------
@@ -184,11 +186,11 @@ CREATE TABLE  icinga_conninfo (
   disposition TEXT  default '',
   connect_source TEXT  default '',
   connect_type TEXT  default '',
-  connect_time timestamp with time zone default '1970-01-01 00:00:00+00',
-  disconnect_time timestamp with time zone default '1970-01-01 00:00:00+00',
-  last_checkin_time timestamp with time zone default '1970-01-01 00:00:00+00',
-  data_start_time timestamp with time zone default '1970-01-01 00:00:00+00',
-  data_end_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  connect_time timestamp,
+  disconnect_time timestamp,
+  last_checkin_time timestamp,
+  data_start_time timestamp,
+  data_end_time timestamp,
   bytes_processed bigint  default 0,
   lines_processed bigint  default 0,
   entries_processed bigint  default 0,
@@ -207,6 +209,7 @@ CREATE TABLE  icinga_contactgroups (
   config_type INTEGER  default 0,
   contactgroup_object_id bigint default 0,
   alias TEXT  default '',
+  config_hash varchar(64) DEFAULT NULL,
   CONSTRAINT PK_contactgroup_id PRIMARY KEY (contactgroup_id) ,
   CONSTRAINT UQ_contactgroups UNIQUE (instance_id,config_type,contactgroup_object_id)
 );
@@ -222,6 +225,7 @@ CREATE TABLE  icinga_contactgroup_members (
   instance_id bigint default 0,
   contactgroup_id bigint default 0,
   contact_object_id bigint default 0,
+  session_token INTEGER default NULL,
   CONSTRAINT PK_contactgroup_member_id PRIMARY KEY (contactgroup_member_id)
 );
 
@@ -235,9 +239,9 @@ CREATE TABLE  icinga_contactnotificationmethods (
   contactnotificationmethod_id bigserial,
   instance_id bigint default 0,
   contactnotification_id bigint default 0,
-  start_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  start_time timestamp,
   start_time_usec INTEGER  default 0,
-  end_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  end_time timestamp,
   end_time_usec INTEGER  default 0,
   command_object_id bigint default 0,
   command_args TEXT  default '',
@@ -256,9 +260,9 @@ CREATE TABLE  icinga_contactnotifications (
   instance_id bigint default 0,
   notification_id bigint default 0,
   contact_object_id bigint default 0,
-  start_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  start_time timestamp,
   start_time_usec INTEGER  default 0,
-  end_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  end_time timestamp,
   end_time_usec INTEGER  default 0,
   CONSTRAINT PK_contactnotification_id PRIMARY KEY (contactnotification_id) ,
   CONSTRAINT UQ_contactnotifications UNIQUE (instance_id,contact_object_id,start_time,start_time_usec)
@@ -294,6 +298,7 @@ CREATE TABLE  icinga_contacts (
   notify_host_unreachable INTEGER  default 0,
   notify_host_flapping INTEGER  default 0,
   notify_host_downtime INTEGER  default 0,
+  config_hash varchar(64) DEFAULT NULL,
   CONSTRAINT PK_contact_id PRIMARY KEY (contact_id) ,
   CONSTRAINT UQ_contacts UNIQUE (instance_id,config_type,contact_object_id)
 ) ;
@@ -308,11 +313,11 @@ CREATE TABLE  icinga_contactstatus (
   contactstatus_id bigserial,
   instance_id bigint default 0,
   contact_object_id bigint default 0,
-  status_update_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  status_update_time timestamp,
   host_notifications_enabled INTEGER  default 0,
   service_notifications_enabled INTEGER  default 0,
-  last_host_notification timestamp with time zone default '1970-01-01 00:00:00+00',
-  last_service_notification timestamp with time zone default '1970-01-01 00:00:00+00',
+  last_host_notification timestamp,
+  last_service_notification timestamp,
   modified_attributes INTEGER  default 0,
   modified_host_attributes INTEGER  default 0,
   modified_service_attributes INTEGER  default 0,
@@ -384,7 +389,7 @@ CREATE TABLE  icinga_customvariablestatus (
   customvariablestatus_id bigserial,
   instance_id bigint default 0,
   object_id bigint default 0,
-  status_update_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  status_update_time timestamp,
   has_been_modified INTEGER  default 0,
   varname TEXT  default '',
   varvalue TEXT  default '',
@@ -406,8 +411,8 @@ CREATE TABLE  icinga_dbversion (
   dbversion_id bigserial,
   name TEXT  default '',
   version TEXT  default '',
-  create_time timestamp with time zone default '1970-01-01 00:00:00+00',
-  modify_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  create_time timestamp,
+  modify_time timestamp,
   CONSTRAINT PK_dbversion_id PRIMARY KEY (dbversion_id) ,
   CONSTRAINT UQ_dbversion UNIQUE (name)
 ) ;
@@ -423,26 +428,25 @@ CREATE TABLE  icinga_downtimehistory (
   instance_id bigint default 0,
   downtime_type INTEGER  default 0,
   object_id bigint default 0,
-  entry_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  entry_time timestamp,
   author_name TEXT  default '',
   comment_data TEXT  default '',
   internal_downtime_id bigint default 0,
   triggered_by_id bigint default 0,
   is_fixed INTEGER  default 0,
   duration BIGINT  default 0,
-  scheduled_start_time timestamp with time zone default '1970-01-01 00:00:00+00',
-  scheduled_end_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  scheduled_start_time timestamp,
+  scheduled_end_time timestamp,
   was_started INTEGER  default 0,
-  actual_start_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  actual_start_time timestamp,
   actual_start_time_usec INTEGER  default 0,
-  actual_end_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  actual_end_time timestamp,
   actual_end_time_usec INTEGER  default 0,
   was_cancelled INTEGER  default 0,
   is_in_effect INTEGER  default 0,
-  trigger_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  trigger_time timestamp,
   name TEXT default NULL,
-  CONSTRAINT PK_downtimehistory_id PRIMARY KEY (downtimehistory_id) ,
-  CONSTRAINT UQ_downtimehistory UNIQUE (instance_id,object_id,entry_time,internal_downtime_id)
+  CONSTRAINT PK_downtimehistory_id PRIMARY KEY (downtimehistory_id)
 ) ;
 
 -- --------------------------------------------------------
@@ -458,9 +462,9 @@ CREATE TABLE  icinga_eventhandlers (
   object_id bigint default 0,
   state INTEGER  default 0,
   state_type INTEGER  default 0,
-  start_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  start_time timestamp,
   start_time_usec INTEGER  default 0,
-  end_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  end_time timestamp,
   end_time_usec INTEGER  default 0,
   command_object_id bigint default 0,
   command_args TEXT  default '',
@@ -484,7 +488,7 @@ CREATE TABLE  icinga_eventhandlers (
 CREATE TABLE  icinga_externalcommands (
   externalcommand_id bigserial,
   instance_id bigint default 0,
-  entry_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  entry_time timestamp,
   command_type INTEGER  default 0,
   command_name TEXT  default '',
   command_args TEXT  default '',
@@ -500,7 +504,7 @@ CREATE TABLE  icinga_externalcommands (
 CREATE TABLE  icinga_flappinghistory (
   flappinghistory_id bigserial,
   instance_id bigint default 0,
-  event_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  event_time timestamp,
   event_time_usec INTEGER  default 0,
   event_type INTEGER  default 0,
   reason_type INTEGER  default 0,
@@ -509,7 +513,7 @@ CREATE TABLE  icinga_flappinghistory (
   percent_state_change double precision  default 0,
   low_threshold double precision  default 0,
   high_threshold double precision  default 0,
-  comment_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  comment_time timestamp,
   internal_comment_id bigint default 0,
   CONSTRAINT PK_flappinghistory_id PRIMARY KEY (flappinghistory_id)
 ) ;
@@ -530,9 +534,9 @@ CREATE TABLE  icinga_hostchecks (
   max_check_attempts INTEGER  default 0,
   state INTEGER  default 0,
   state_type INTEGER  default 0,
-  start_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  start_time timestamp,
   start_time_usec INTEGER  default 0,
-  end_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  end_time timestamp,
   end_time_usec INTEGER  default 0,
   command_object_id bigint default 0,
   command_args TEXT  default '',
@@ -637,6 +641,7 @@ CREATE TABLE  icinga_hostgroups (
   notes TEXT  default NULL,
   notes_url TEXT  default NULL,
   action_url TEXT  default NULL,
+  config_hash varchar(64) DEFAULT NULL,
   CONSTRAINT PK_hostgroup_id PRIMARY KEY (hostgroup_id) ,
   CONSTRAINT UQ_hostgroups UNIQUE (instance_id,hostgroup_object_id)
 ) ;
@@ -652,6 +657,7 @@ CREATE TABLE  icinga_hostgroup_members (
   instance_id bigint default 0,
   hostgroup_id bigint default 0,
   host_object_id bigint default 0,
+  session_token INTEGER default NULL,
   CONSTRAINT PK_hostgroup_member_id PRIMARY KEY (hostgroup_member_id)
 ) ;
 
@@ -721,6 +727,7 @@ CREATE TABLE  icinga_hosts (
   x_3d double precision  default 0,
   y_3d double precision  default 0,
   z_3d double precision  default 0,
+  config_hash varchar(64) DEFAULT NULL,
   CONSTRAINT PK_host_id PRIMARY KEY (host_id) ,
   CONSTRAINT UQ_hosts UNIQUE (instance_id,config_type,host_object_id)
 ) ;
@@ -735,28 +742,28 @@ CREATE TABLE  icinga_hoststatus (
   hoststatus_id bigserial,
   instance_id bigint default 0,
   host_object_id bigint default 0,
-  status_update_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  status_update_time timestamp,
   output TEXT  default '',
   long_output TEXT  default '',
   perfdata TEXT  default '',
-  check_source TEXT  default '',
+  check_source varchar(255) default '',
   current_state INTEGER  default 0,
   has_been_checked INTEGER  default 0,
   should_be_scheduled INTEGER  default 0,
   current_check_attempt INTEGER  default 0,
   max_check_attempts INTEGER  default 0,
-  last_check timestamp with time zone default '1970-01-01 00:00:00+00',
-  next_check timestamp with time zone default '1970-01-01 00:00:00+00',
+  last_check timestamp,
+  next_check timestamp,
   check_type INTEGER  default 0,
-  last_state_change timestamp with time zone default '1970-01-01 00:00:00+00',
-  last_hard_state_change timestamp with time zone default '1970-01-01 00:00:00+00',
+  last_state_change timestamp,
+  last_hard_state_change timestamp,
   last_hard_state INTEGER  default 0,
-  last_time_up timestamp with time zone default '1970-01-01 00:00:00+00',
-  last_time_down timestamp with time zone default '1970-01-01 00:00:00+00',
-  last_time_unreachable timestamp with time zone default '1970-01-01 00:00:00+00',
+  last_time_up timestamp,
+  last_time_down timestamp,
+  last_time_unreachable timestamp,
   state_type INTEGER  default 0,
-  last_notification timestamp with time zone default '1970-01-01 00:00:00+00',
-  next_notification timestamp with time zone default '1970-01-01 00:00:00+00',
+  last_notification timestamp,
+  next_notification timestamp,
   no_more_notifications INTEGER  default 0,
   notifications_enabled INTEGER  default 0,
   problem_has_been_acknowledged INTEGER  default 0,
@@ -850,8 +857,8 @@ CREATE TABLE  icinga_instances (
 CREATE TABLE  icinga_logentries (
   logentry_id bigserial,
   instance_id bigint default 0,
-  logentry_time timestamp with time zone default '1970-01-01 00:00:00+00',
-  entry_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  logentry_time timestamp,
+  entry_time timestamp,
   entry_time_usec INTEGER  default 0,
   logentry_type INTEGER  default 0,
   logentry_data TEXT  default '',
@@ -873,9 +880,9 @@ CREATE TABLE  icinga_notifications (
   notification_type INTEGER  default 0,
   notification_reason INTEGER  default 0,
   object_id bigint default 0,
-  start_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  start_time timestamp,
   start_time_usec INTEGER  default 0,
-  end_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  end_time timestamp,
   end_time_usec INTEGER  default 0,
   state INTEGER  default 0,
   output TEXT  default '',
@@ -914,7 +921,7 @@ CREATE TABLE  icinga_processevents (
   processevent_id bigserial,
   instance_id bigint default 0,
   event_type INTEGER  default 0,
-  event_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  event_time timestamp,
   event_time_usec INTEGER  default 0,
   process_id bigint default 0,
   program_name TEXT  default '',
@@ -933,17 +940,17 @@ CREATE TABLE  icinga_programstatus (
   programstatus_id bigserial,
   instance_id bigint default 0,
   program_version TEXT  default NULL,
-  status_update_time timestamp with time zone default '1970-01-01 00:00:00+00',
-  program_start_time timestamp with time zone default '1970-01-01 00:00:00+00',
-  program_end_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  status_update_time timestamp,
+  program_start_time timestamp,
+  program_end_time timestamp,
   is_currently_running INTEGER  default 0,
   endpoint_name TEXT  default '',
   process_id bigint default 0,
   daemon_mode INTEGER  default 0,
-  last_command_check timestamp with time zone default '1970-01-01 00:00:00+00',
-  last_log_rotation timestamp with time zone default '1970-01-01 00:00:00+00',
+  last_command_check timestamp,
+  last_log_rotation timestamp,
   notifications_enabled INTEGER  default 0,
-  disable_notif_expire_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  disable_notif_expire_time timestamp,
   active_service_checks_enabled INTEGER  default 0,
   passive_service_checks_enabled INTEGER  default 0,
   active_host_checks_enabled INTEGER  default 0,
@@ -988,23 +995,23 @@ CREATE TABLE  icinga_scheduleddowntime (
   instance_id bigint default 0,
   downtime_type INTEGER  default 0,
   object_id bigint default 0,
-  entry_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  entry_time timestamp,
   author_name TEXT  default '',
   comment_data TEXT  default '',
   internal_downtime_id bigint default 0,
   triggered_by_id bigint default 0,
   is_fixed INTEGER  default 0,
   duration BIGINT  default 0,
-  scheduled_start_time timestamp with time zone default '1970-01-01 00:00:00+00',
-  scheduled_end_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  scheduled_start_time timestamp,
+  scheduled_end_time timestamp,
   was_started INTEGER  default 0,
-  actual_start_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  actual_start_time timestamp,
   actual_start_time_usec INTEGER  default 0,
   is_in_effect INTEGER  default 0,
-  trigger_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  trigger_time timestamp,
   name TEXT default NULL,
-  CONSTRAINT PK_scheduleddowntime_id PRIMARY KEY (scheduleddowntime_id) ,
-  CONSTRAINT UQ_scheduleddowntime UNIQUE (instance_id,object_id,entry_time,internal_downtime_id)
+  session_token INTEGER default NULL,
+  CONSTRAINT PK_scheduleddowntime_id PRIMARY KEY (scheduleddowntime_id)
 ) ;
 
 -- --------------------------------------------------------
@@ -1022,9 +1029,9 @@ CREATE TABLE  icinga_servicechecks (
   max_check_attempts INTEGER  default 0,
   state INTEGER  default 0,
   state_type INTEGER  default 0,
-  start_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  start_time timestamp,
   start_time_usec INTEGER  default 0,
-  end_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  end_time timestamp,
   end_time_usec INTEGER  default 0,
   command_object_id bigint default 0,
   command_args TEXT  default '',
@@ -1131,6 +1138,7 @@ CREATE TABLE  icinga_servicegroups (
   notes TEXT  default NULL,
   notes_url TEXT  default NULL,
   action_url TEXT  default NULL,
+  config_hash varchar(64) DEFAULT NULL,
   CONSTRAINT PK_servicegroup_id PRIMARY KEY (servicegroup_id) ,
   CONSTRAINT UQ_servicegroups UNIQUE (instance_id,config_type,servicegroup_object_id)
 ) ;
@@ -1146,6 +1154,7 @@ CREATE TABLE  icinga_servicegroup_members (
   instance_id bigint default 0,
   servicegroup_id bigint default 0,
   service_object_id bigint default 0,
+  session_token INTEGER default NULL,
   CONSTRAINT PK_servicegroup_member_id PRIMARY KEY (servicegroup_member_id)
 ) ;
 
@@ -1208,6 +1217,7 @@ CREATE TABLE  icinga_services (
   action_url TEXT  default '',
   icon_image TEXT  default '',
   icon_image_alt TEXT  default '',
+  config_hash varchar(64) DEFAULT NULL,
   CONSTRAINT PK_service_id PRIMARY KEY (service_id) ,
   CONSTRAINT UQ_services UNIQUE (instance_id,config_type,service_object_id)
 ) ;
@@ -1222,29 +1232,29 @@ CREATE TABLE  icinga_servicestatus (
   servicestatus_id bigserial,
   instance_id bigint default 0,
   service_object_id bigint default 0,
-  status_update_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  status_update_time timestamp,
   output TEXT  default '',
   long_output TEXT  default '',
   perfdata TEXT  default '',
-  check_source TEXT  default '',
+  check_source varchar(255) default '',
   current_state INTEGER  default 0,
   has_been_checked INTEGER  default 0,
   should_be_scheduled INTEGER  default 0,
   current_check_attempt INTEGER  default 0,
   max_check_attempts INTEGER  default 0,
-  last_check timestamp with time zone default '1970-01-01 00:00:00+00',
-  next_check timestamp with time zone default '1970-01-01 00:00:00+00',
+  last_check timestamp,
+  next_check timestamp,
   check_type INTEGER  default 0,
-  last_state_change timestamp with time zone default '1970-01-01 00:00:00+00',
-  last_hard_state_change timestamp with time zone default '1970-01-01 00:00:00+00',
+  last_state_change timestamp,
+  last_hard_state_change timestamp,
   last_hard_state INTEGER  default 0,
-  last_time_ok timestamp with time zone default '1970-01-01 00:00:00+00',
-  last_time_warning timestamp with time zone default '1970-01-01 00:00:00+00',
-  last_time_unknown timestamp with time zone default '1970-01-01 00:00:00+00',
-  last_time_critical timestamp with time zone default '1970-01-01 00:00:00+00',
+  last_time_ok timestamp,
+  last_time_warning timestamp,
+  last_time_unknown timestamp,
+  last_time_critical timestamp,
   state_type INTEGER  default 0,
-  last_notification timestamp with time zone default '1970-01-01 00:00:00+00',
-  next_notification timestamp with time zone default '1970-01-01 00:00:00+00',
+  last_notification timestamp,
+  next_notification timestamp,
   no_more_notifications INTEGER  default 0,
   notifications_enabled INTEGER  default 0,
   problem_has_been_acknowledged INTEGER  default 0,
@@ -1311,7 +1321,7 @@ CREATE TABLE  icinga_service_contacts (
 CREATE TABLE  icinga_statehistory (
   statehistory_id bigserial,
   instance_id bigint default 0,
-  state_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  state_time timestamp,
   state_time_usec INTEGER  default 0,
   object_id bigint default 0,
   state_change INTEGER  default 0,
@@ -1323,7 +1333,7 @@ CREATE TABLE  icinga_statehistory (
   last_hard_state INTEGER  default '-1',
   output TEXT  default '',
   long_output TEXT  default '',
-  check_source TEXT default '',
+  check_source varchar(255) default '',
   CONSTRAINT PK_statehistory_id PRIMARY KEY (statehistory_id)
 ) ;
 
@@ -1336,9 +1346,9 @@ CREATE TABLE  icinga_statehistory (
 CREATE TABLE  icinga_systemcommands (
   systemcommand_id bigserial,
   instance_id bigint default 0,
-  start_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  start_time timestamp,
   start_time_usec INTEGER  default 0,
-  end_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  end_time timestamp,
   end_time_usec INTEGER  default 0,
   command_line TEXT  default '',
   timeout INTEGER  default 0,
@@ -1363,6 +1373,7 @@ CREATE TABLE  icinga_timeperiods (
   config_type INTEGER  default 0,
   timeperiod_object_id bigint default 0,
   alias TEXT  default '',
+  config_hash varchar(64) DEFAULT NULL,
   CONSTRAINT PK_timeperiod_id PRIMARY KEY (timeperiod_id) ,
   CONSTRAINT UQ_timeperiods UNIQUE (instance_id,config_type,timeperiod_object_id)
 ) ;
@@ -1400,6 +1411,7 @@ CREATE TABLE  icinga_endpoints (
   config_type integer default 0,
   identity text DEFAULT NULL,
   node text DEFAULT NULL,
+  config_hash varchar(64) DEFAULT NULL,
   CONSTRAINT PK_endpoint_id PRIMARY KEY (endpoint_id) ,
   CONSTRAINT UQ_endpoints UNIQUE (instance_id,config_type,endpoint_object_id)
 ) ;
@@ -1415,7 +1427,7 @@ CREATE TABLE  icinga_endpointstatus (
   instance_id bigint default 0,
   endpoint_object_id bigint default 0,
   zone_object_id bigint default 0,
-  status_update_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  status_update_time timestamp,
   identity text DEFAULT NULL,
   node text DEFAULT NULL,
   is_connected integer default 0,
@@ -1434,6 +1446,7 @@ CREATE TABLE  icinga_zones (
   parent_zone_object_id bigint default 0,
   config_type integer default 0,
   is_global integer default 0,
+  config_hash varchar(64) DEFAULT NULL,
   CONSTRAINT PK_zone_id PRIMARY KEY (zone_id) ,
   CONSTRAINT UQ_zones UNIQUE (instance_id,config_type,zone_object_id)
 ) ;
@@ -1449,7 +1462,7 @@ CREATE TABLE  icinga_zonestatus (
   instance_id bigint default 0,
   zone_object_id bigint default 0,
   parent_zone_object_id bigint default 0,
-  status_update_time timestamp with time zone default '1970-01-01 00:00:00+00',
+  status_update_time timestamp,
   CONSTRAINT PK_zonestatus_id PRIMARY KEY (zonestatus_id) ,
   CONSTRAINT UQ_zonestatus UNIQUE (zone_object_id)
 ) ;
@@ -1670,13 +1683,51 @@ CREATE INDEX sla_idx_obj ON icinga_objects (objecttype_id, is_active, name1);
 -- #4985
 CREATE INDEX commenthistory_delete_idx ON icinga_commenthistory (instance_id, comment_time, internal_comment_id);
 
--- #10436
-CREATE INDEX cv_session_del_idx ON icinga_customvariables (session_token);
-CREATE INDEX cvs_session_del_idx ON icinga_customvariablestatus (session_token);
+-- #10070
+CREATE INDEX idx_comments_object_id on icinga_comments(object_id);
+CREATE INDEX idx_scheduleddowntime_object_id on icinga_scheduleddowntime(object_id);
+
+-- #10066
+CREATE INDEX idx_endpoints_object_id on icinga_endpoints(endpoint_object_id);
+CREATE INDEX idx_endpointstatus_object_id on icinga_endpointstatus(endpoint_object_id);
+
+CREATE INDEX idx_endpoints_zone_object_id on icinga_endpoints(zone_object_id);
+CREATE INDEX idx_endpointstatus_zone_object_id on icinga_endpointstatus(zone_object_id);
+
+CREATE INDEX idx_zones_object_id on icinga_zones(zone_object_id);
+CREATE INDEX idx_zonestatus_object_id on icinga_zonestatus(zone_object_id);
+
+CREATE INDEX idx_zones_parent_object_id on icinga_zones(parent_zone_object_id);
+CREATE INDEX idx_zonestatus_parent_object_id on icinga_zonestatus(parent_zone_object_id);
+
+-- #12210
+CREATE INDEX idx_comments_session_del ON icinga_comments (instance_id, session_token);
+CREATE INDEX idx_downtimes_session_del ON icinga_scheduleddowntime (instance_id, session_token);
+
+-- #12107
+CREATE INDEX idx_statehistory_cleanup on icinga_statehistory(instance_id, state_time);
+
+-- #12435
+CREATE INDEX idx_customvariables_object_id on icinga_customvariables(object_id);
+CREATE INDEX idx_contactgroup_members_object_id on icinga_contactgroup_members(contact_object_id);
+CREATE INDEX idx_hostgroup_members_object_id on icinga_hostgroup_members(host_object_id);
+CREATE INDEX idx_servicegroup_members_object_id on icinga_servicegroup_members(service_object_id);
+CREATE INDEX idx_servicedependencies_dependent_service_object_id on icinga_servicedependencies(dependent_service_object_id);
+CREATE INDEX idx_hostdependencies_dependent_host_object_id on icinga_hostdependencies(dependent_host_object_id);
+CREATE INDEX idx_service_contacts_service_id on icinga_service_contacts(service_id);
+CREATE INDEX idx_host_contacts_host_id on icinga_host_contacts(host_id);
+
+-- #5458
+CREATE INDEX idx_downtimehistory_remove ON icinga_downtimehistory (object_id, entry_time, scheduled_start_time, scheduled_end_time);
+CREATE INDEX idx_scheduleddowntime_remove ON icinga_scheduleddowntime (object_id, entry_time, scheduled_start_time, scheduled_end_time);
+
+-- #5492
+CREATE INDEX idx_commenthistory_remove ON icinga_commenthistory (object_id, entry_time);
+CREATE INDEX idx_comments_remove ON icinga_comments (object_id, entry_time);
 
 -- -----------------------------------------
 -- set dbversion
 -- -----------------------------------------
 
-SELECT updatedbversion('1.14.0');
+SELECT updatedbversion('1.14.3');
 
